/* Skeleton configurable module.
 *
 * Skeleton configurable module (c) 2005 PegSoft
 * Contact us at pegsoft@pegsoft.net
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program (see the file COPYING); if not, write to the
 * Free Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */

#ifndef MODULE_H
#define MODULE_H

/*************************************************************************/

#include <modules/module.h>

/*************************************************************************/

namespace modules { class Core; }

/*************************************************************************/

/// Namespace for module skelconf.

/** The classes and extern functions and variables of each module must
  * be in a namespace of their own, to avoid name conflicts.
  *
  * The namespace name must be the same as the module name. */
	
namespace skelconf 
{

/*************************************************************************/

class Directives;

/*************************************************************************/

/// The module version.
static int const skelconf_version = 0x01000000;

/// The skelconf module class.

/** Each module declares a new class inherited from the Module class.
  * The Module::version() function must be overriden. Other
  * functions may be overriden too; see the documentation of the
  * Module class for more information.
  *
  * As this is a configurable module, we also override the Module::config()
  * function. */

class SkelConf : public modules::Module
{
	public:
		/// Constructor.
		SkelConf(modules::Core &core);
		/// Destructor.
		~SkelConf();
		
		/// Overrides Module::config() -- returns &m_cd->parser().
		virtual conf::ConfQ *config(modules::Core &core,
				conf::ConfGlobalQ &global);
		
		/// Implements Module::version().
		virtual int version() const { return skelconf_version; }
		
		/// Returns the core module.
		modules::Core &core() { return *m_core; }
		
		/// Returns the configuration directives.
		/** The configuration directives object is created in
		  * the constructor. */
		Directives const &cd() const { return *m_cd; }
	private:
		modules::Core *m_core;
		Directives *m_cd;
};

/*************************************************************************/

} /* namespace skelconf */

/*************************************************************************/

#endif /* MODULE_H */
